.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

.. image:: https://github.com/collective/acentoweb.addusergroup/actions/workflows/plone-package.yml/badge.svg
    :target: https://github.com/collective/acentoweb.addusergroup/actions/workflows/plone-package.yml

.. image:: https://coveralls.io/repos/github/collective/acentoweb.addusergroup/badge.svg?branch=main
    :target: https://coveralls.io/github/collective/acentoweb.addusergroup?branch=main
    :alt: Coveralls

.. image:: https://codecov.io/gh/collective/acentoweb.addusergroup/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/collective/acentoweb.addusergroup

.. image:: https://img.shields.io/pypi/v/acentoweb.addusergroup.svg
    :target: https://pypi.python.org/pypi/acentoweb.addusergroup/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/status/acentoweb.addusergroup.svg
    :target: https://pypi.python.org/pypi/acentoweb.addusergroup
    :alt: Egg Status

.. image:: https://img.shields.io/pypi/pyversions/acentoweb.addusergroup.svg?style=plastic   :alt: Supported - Python Versions

.. image:: https://img.shields.io/pypi/l/acentoweb.addusergroup.svg
    :target: https://pypi.python.org/pypi/acentoweb.addusergroup/
    :alt: License


======================
acentoweb.addusergroup
======================

Adds new users automatically to groups

Features
--------

- Adds settings to the medialog control panel
- the Group settings will add all users to these groups on login

 


Installation
------------

Install acentoweb.addusergroup by adding it to your buildout::

    [buildout]

    ...

    eggs =
        acentoweb.addusergroup


and then running ``bin/buildout``


Authors
-------

Espen Moe-Nilssen

 


Contribute
----------

- Issue Tracker: https://github.com/collective/acentoweb.addusergroup/issues
- Source Code: https://github.com/collective/acentoweb.addusergroup
- Documentation: https://docs.plone.org/foo/bar


Support
-------

If you are having issues, please let us know.
We have a mailing list located at: project@example.com


License
-------

The project is licensed under the GPLv2.
